diff --git a/.gitignore b/.gitignore
index e15d6c8f7..ae018efb6 100644
--- a/.gitignore
+++ b/.gitignore
@@ -11,6 +11,7 @@
.settings
node_modules
npm-debug.log
+archive/
/books
/notes
/states
@@ -18,7 +19,6 @@ npm-debug.log
/web
private/
src/
-static/
tmp/
_site
.sass-cache
diff --git a/_config.yml b/_config.yml
index c921bd525..6b2487f96 100644
--- a/_config.yml
+++ b/_config.yml
@@ -17,7 +17,7 @@ right_brace: "}"
# Build settings
-exclude: ["index.html", "**/index.html", "logs", "node_modules", "**/c64", "**/private", "src", "**/src", "**/static", "tmp", "videos", "web", ".git", ".idea"]
+exclude: ["index.html", "**/index.html", "**/archive", "logs", "node_modules", "**/c64", "**/private", "src", "**/src", "tmp", "videos", "web", ".git", ".idea"]
markdown: kramdown
kramdown:
input: GFM
diff --git a/_layouts/viewer.html b/_layouts/viewer.html
index 7cda7240e..2d185d246 100644
--- a/_layouts/viewer.html
+++ b/_layouts/viewer.html
@@ -38,7 +38,7 @@
var totalPages = parseInt(aParms['total'], 10) || 999;
var frame = document.getElementById('framePDF');
if (pdf && frame) {
- pdf = pdf.replace('/static/', '/');
+ pdf = pdf.replace('/archive/', '/');
var i = pdf.indexOf("/pages/");
if (i > 0) {
var sReturnLink = pdf.substr(0, i+1);
diff --git a/apps/README.md b/apps/README.md
index 4d9521f35..5a19797c1 100644
--- a/apps/README.md
+++ b/apps/README.md
@@ -82,7 +82,7 @@ have saved that JSON-encoded image as static file on the server, and then added
<disk> entry:
-
+
...
diff --git a/apps/pc/1981/visicalc/manifest.xml b/apps/pc/1981/visicalc/manifest.xml
index 74a7714af..0c33fb670 100644
--- a/apps/pc/1981/visicalc/manifest.xml
+++ b/apps/pc/1981/visicalc/manifest.xml
@@ -12,7 +12,7 @@
December 16, 1981
Lotus Development
-
+
VC.COM
README.md
VisiCalc License
diff --git a/apps/pc/1982/esuite/manifest.xml b/apps/pc/1982/esuite/manifest.xml
index 5ee5fca0c..2d702542e 100644
--- a/apps/pc/1982/esuite/manifest.xml
+++ b/apps/pc/1982/esuite/manifest.xml
@@ -8,7 +8,7 @@
Armonk Corporation
1982
-
+
Executive Suite (1982)
ESUITE.COM
GAME.DAT
diff --git a/apps/pc/1985/rogue/manifest.xml b/apps/pc/1985/rogue/manifest.xml
index 843890118..98994c09a 100644
--- a/apps/pc/1985/rogue/manifest.xml
+++ b/apps/pc/1985/rogue/manifest.xml
@@ -12,7 +12,7 @@
Ken Arnold
Jon Lane
Michael Toy
-
+
Rogue (1985)
MKOPT.EXE
ROGUE.COM
diff --git a/apps/pc/1987/thinktank/manifest.xml b/apps/pc/1987/thinktank/manifest.xml
index dae73977f..70c2b8467 100644
--- a/apps/pc/1987/thinktank/manifest.xml
+++ b/apps/pc/1987/thinktank/manifest.xml
@@ -7,7 +7,7 @@
Productivity
Living Videotext
September 25, 1987
-
+
ThinkTank 2.41NP
AUTOEXEC.BAT
READ_ME.DB
diff --git a/apps/pc/1988/moria/manifest.xml b/apps/pc/1988/moria/manifest.xml
index fbc13d125..feb3db3b5 100644
--- a/apps/pc/1988/moria/manifest.xml
+++ b/apps/pc/1988/moria/manifest.xml
@@ -14,7 +14,7 @@
D. G. Kneller
MSDOS port
-
+
Moria v4.872
CONFIG.DOC
GOD
diff --git a/apps/pc/1992/moria/manifest.xml b/apps/pc/1992/moria/manifest.xml
index 8de060385..df9bdd36f 100644
--- a/apps/pc/1992/moria/manifest.xml
+++ b/apps/pc/1992/moria/manifest.xml
@@ -92,7 +92,7 @@
Ben Schreiber
Macintosh port for Think C
-
+
Moria 5.5
EXP.DOC
MORIA.CNF
diff --git a/apps/pc/README.md b/apps/pc/README.md
index 9d2e18cb5..b41c04374 100644
--- a/apps/pc/README.md
+++ b/apps/pc/README.md
@@ -32,12 +32,12 @@ Next, the [manifest](1981/visicalc/manifest.xml) required a disk image containin
(VC.COM). We used the [DiskDump](/modules/diskdump/) module to create that disk image:
cd apps/pc/1981/visicalc
- node ../../../../modules/diskdump/bin/diskdump --path="static/VC.COM;../README.md" --format=json --output=disk.json --manifest
+ node ../../../../modules/diskdump/bin/diskdump --path="archive/VC.COM;../README.md" --format=json --output=disk.json --manifest
The DiskDump command created a disk image named "disk.json" containing two files ("VC.COM" from the "static" subdirectory,
and "README.md" from the "static" parent directory) and automatically added that disk image to the demo's [manifest](1981/visicalc/manifest.xml):
-
+
VC.COM
README.md
diff --git a/devices/pc/machine/5170/ega/640kb/rev1/debugger/manifest.xml b/devices/pc/machine/5170/ega/640kb/rev1/debugger/manifest.xml
index 798c1bf70..a9cfd49d4 100644
--- a/devices/pc/machine/5170/ega/640kb/rev1/debugger/manifest.xml
+++ b/devices/pc/machine/5170/ega/640kb/rev1/debugger/manifest.xml
@@ -4,7 +4,7 @@
IBM PC AT References
IBM 5170 Technical Reference (March 1984)
-
+
I/O Address Map
CMOS Addresses
BIOS Map
@@ -16,7 +16,7 @@
80286 and 80287 Programmers Reference Manual (1987)
-
+
Memory Organization and Segmentation
VERR/VERW
diff --git a/devices/pc/rom/compaq/bios/deskpro386/README.md b/devices/pc/rom/compaq/bios/deskpro386/README.md
index b85c36e27..4287f9ad4 100644
--- a/devices/pc/rom/compaq/bios/deskpro386/README.md
+++ b/devices/pc/rom/compaq/bios/deskpro386/README.md
@@ -53,8 +53,8 @@ Similarly, [1989-04-14.json](1989-04-14/1989-04-14.json) was generated by first
from the two 16Kb BIN files provided by [Al Kossow](http://www.vintage-computer.com/vcforum/member.php?2256-Al-Kossow):
cd 1989-04-14
- filedump --file=static/109592-005.U11.bin --merge=static/109591-005.U13.bin --output=static/1989-04-14.rom --format=rom
- filedump --file=static/1989-04-14.rom --output=1989-04-14.json
+ filedump --file=archive/109592-005.U11.bin --merge=archive/109591-005.U13.bin --output=archive/1989-04-14.rom --format=rom
+ filedump --file=archive/1989-04-14.rom --output=1989-04-14.json
Dumping the ROMs
---
diff --git a/devices/pc/video/ibm/ega/README.md b/devices/pc/video/ibm/ega/README.md
index 81affd93b..cd6fef871 100644
--- a/devices/pc/video/ibm/ega/README.md
+++ b/devices/pc/video/ibm/ega/README.md
@@ -9,7 +9,7 @@ IBM EGA ROM
To (re)build the JSON-encoded IBM EGA ROM with symbols, run the following command:
- filedump --file=static/ibm-ega.rom --format=bytes --decimal
+ filedump --file=archive/ibm-ega.rom --format=bytes --decimal
The symbol information in the MAP file will be automatically converted and appended to the dump of the ROM file.
diff --git a/disks/pc/apps/lotus/123/1.0a/manifest.xml b/disks/pc/apps/lotus/123/1.0a/manifest.xml
index 3c1082dd8..c3f8b8d8b 100644
--- a/disks/pc/apps/lotus/123/1.0a/manifest.xml
+++ b/disks/pc/apps/lotus/123/1.0a/manifest.xml
@@ -7,16 +7,16 @@
Productivity
Lotus
-
+
Lotus 1-2-3 (System)
-
+
Lotus 1-2-3 (Utility)
-
+
Lotus 1-2-3 (Graph)
-
+
Lotus 1-2-3 (Tutorial)
diff --git a/disks/pc/apps/microsoft/chart/2.02/manifest.xml b/disks/pc/apps/microsoft/chart/2.02/manifest.xml
index e37e3ab97..02fcddac7 100644
--- a/disks/pc/apps/microsoft/chart/2.02/manifest.xml
+++ b/disks/pc/apps/microsoft/chart/2.02/manifest.xml
@@ -25,7 +25,7 @@
I would much rather post copies of original distribution disks here, but this is all we've currently got.
-
+
MS Chart 2.02 (Unofficial)
diff --git a/disks/pc/apps/microsoft/winword/2.0c/manifest.xml b/disks/pc/apps/microsoft/winword/2.0c/manifest.xml
index 0e68a54e5..baaeccecc 100644
--- a/disks/pc/apps/microsoft/winword/2.0c/manifest.xml
+++ b/disks/pc/apps/microsoft/winword/2.0c/manifest.xml
@@ -7,22 +7,22 @@
Word Processor
Microsoft
-
+
Word for Windows 2.0c (Disk 1)
-
+
Word for Windows 2.0c (Disk 2)
-
+
Word for Windows 2.0c (Disk 3)
-
+
Word for Windows 2.0c (Disk 4)
-
+
Word for Windows 2.0c (Disk 5)
-
+
Word for Windows 2.0c (Disk 6)
diff --git a/disks/pc/apps/microsoft/word/3.0/manifest.xml b/disks/pc/apps/microsoft/word/3.0/manifest.xml
index 3fccb8253..9274314ce 100644
--- a/disks/pc/apps/microsoft/word/3.0/manifest.xml
+++ b/disks/pc/apps/microsoft/word/3.0/manifest.xml
@@ -7,22 +7,22 @@
Word Processor
Microsoft
-
+
MS Word 3.0 (Disk 1)
-
+
MS Word 3.0 (Disk 2)
-
+
MS Word 3.0 (Disk 3)
-
+
MS Word 3.0 (Disk 4)
-
+
MS Word 3.0 (Disk 5)
-
+
MS Word 3.0 (Disk 6)
diff --git a/disks/pc/apps/microsoft/word/3.1/manifest.xml b/disks/pc/apps/microsoft/word/3.1/manifest.xml
index 0abf773e0..f7cab82d1 100644
--- a/disks/pc/apps/microsoft/word/3.1/manifest.xml
+++ b/disks/pc/apps/microsoft/word/3.1/manifest.xml
@@ -7,28 +7,28 @@
Word Processor
Microsoft
-
+
MS Word 3.1 (Disk 1)
-
+
MS Word 3.1 (Disk 2)
-
+
MS Word 3.1 (Disk 3)
-
+
MS Word 3.1 (Disk 4)
-
+
MS Word 3.1 (Disk 5)
-
+
MS Word 3.1 (Disk 6)
-
+
MS Word 3.1 (Disk 7)
-
+
MS Word 3.1 (Disk 8)
diff --git a/disks/pc/apps/microsoft/word/5.0/manifest.xml b/disks/pc/apps/microsoft/word/5.0/manifest.xml
index 130ea8af8..d13ca7902 100644
--- a/disks/pc/apps/microsoft/word/5.0/manifest.xml
+++ b/disks/pc/apps/microsoft/word/5.0/manifest.xml
@@ -7,43 +7,43 @@
Word Processor
Microsoft
-
+
MS Word 5.0 (Program 1)
-
+
MS Word 5.0 (Program 2)
-
+
MS Word 5.0 (Spell)
-
+
MS Word 5.0 (Thesaurus)
-
+
MS Word 5.0 (Utilities 1)
-
+
MS Word 5.0 (Utilities 2)
-
+
MS Word 5.0 (Utilities 3)
-
+
MS Word 5.0 (Utilities/Print)
-
+
MS Word 5.0 (Printers 1)
-
+
MS Word 5.0 (Printers 2)
-
+
MS Word 5.0 (Learning Kbd)
-
+
MS Word 5.0 (Learning Mouse)
-
+
MS Word 5.0 (Learning Adv)
diff --git a/disks/pc/cpm/1.1b/manifest.xml b/disks/pc/cpm/1.1b/manifest.xml
index 1eac4d43e..ec8ac959a 100644
--- a/disks/pc/cpm/1.1b/manifest.xml
+++ b/disks/pc/cpm/1.1b/manifest.xml
@@ -9,10 +9,10 @@
Eagle Computer
May 20, 1983
-
+
CP/M-86 (Disk 1)
-
+
CP/M-86 (Disk 2)
diff --git a/disks/pc/diags/ibm/2.20/manifest.xml b/disks/pc/diags/ibm/2.20/manifest.xml
index 8352841b0..5c54e62bc 100644
--- a/disks/pc/diags/ibm/2.20/manifest.xml
+++ b/disks/pc/diags/ibm/2.20/manifest.xml
@@ -8,7 +8,7 @@
IBM
-
+
diff --git a/disks/pc/dos/compaq/1.11/manifest.xml b/disks/pc/dos/compaq/1.11/manifest.xml
index ac0f2f471..0f16f1ea7 100644
--- a/disks/pc/dos/compaq/1.11/manifest.xml
+++ b/disks/pc/dos/compaq/1.11/manifest.xml
@@ -7,7 +7,7 @@
Operating System
Microsoft/COMPAQ
-
+
COMPAQ MS-DOS 1.11
diff --git a/disks/pc/dos/compaq/1.12/manifest.xml b/disks/pc/dos/compaq/1.12/manifest.xml
index e0ec6118e..b8e90868b 100644
--- a/disks/pc/dos/compaq/1.12/manifest.xml
+++ b/disks/pc/dos/compaq/1.12/manifest.xml
@@ -7,7 +7,7 @@
Operating System
Microsoft/COMPAQ
-
+
COMPAQ MS-DOS 1.12
diff --git a/disks/pc/dos/compaq/2.12/manifest.xml b/disks/pc/dos/compaq/2.12/manifest.xml
index 32311cb89..d228f6664 100644
--- a/disks/pc/dos/compaq/2.12/manifest.xml
+++ b/disks/pc/dos/compaq/2.12/manifest.xml
@@ -7,7 +7,7 @@
Operating System
Microsoft/COMPAQ
-
+
COMPAQ MS-DOS 2.12
diff --git a/disks/pc/dos/compaq/3.10/manifest.xml b/disks/pc/dos/compaq/3.10/manifest.xml
index d484c4d21..de9cf7cfb 100644
--- a/disks/pc/dos/compaq/3.10/manifest.xml
+++ b/disks/pc/dos/compaq/3.10/manifest.xml
@@ -8,19 +8,19 @@
Microsoft/COMPAQ
-
+
COMPAQ MS-DOS 3.10 (Disk 1)
-
+
COMPAQ MS-DOS 3.10 (Disk 2)
-
+
COMPAQ MS-DOS 3.10 (Personal)
-
+
COMPAQ PC-DOS 3.20 Support
-
+
COMPAQ DESKPRO 386 (1986)
diff --git a/disks/pc/dos/compaq/3.31/manifest.xml b/disks/pc/dos/compaq/3.31/manifest.xml
index 41463e911..111dd46b7 100644
--- a/disks/pc/dos/compaq/3.31/manifest.xml
+++ b/disks/pc/dos/compaq/3.31/manifest.xml
@@ -8,22 +8,22 @@
Microsoft/COMPAQ
-
+
COMPAQ MS-DOS 3.31 (Disk 1)
-
+
COMPAQ MS-DOS 3.31 (Disk 2)
-
+
COMPAQ MS-DOS 3.31 (Disk 3)
-
+
COMPAQ MS-DOS 3.31 (Disk 4)
-
+
COMPAQ MS-DOS 3.31 (Disk 5)
-
+
COMPAQ MS-DOS 3.31 (Diagnostics)
diff --git a/disks/pc/dos/ibm/1.00/manifest.xml b/disks/pc/dos/ibm/1.00/manifest.xml
index 8c208104c..d6c51a659 100644
--- a/disks/pc/dos/ibm/1.00/manifest.xml
+++ b/disks/pc/dos/ibm/1.00/manifest.xml
@@ -7,5 +7,5 @@
Operating System
IBM/Microsoft
-
+
diff --git a/disks/pc/dos/ibm/1.10/manifest.xml b/disks/pc/dos/ibm/1.10/manifest.xml
index f61360f9e..ec5a0f3ef 100644
--- a/disks/pc/dos/ibm/1.10/manifest.xml
+++ b/disks/pc/dos/ibm/1.10/manifest.xml
@@ -7,5 +7,5 @@
Operating System
IBM/Microsoft
-
+
diff --git a/disks/pc/dos/ibm/2.00/manifest.xml b/disks/pc/dos/ibm/2.00/manifest.xml
index 516ae6178..0d8e43ec3 100644
--- a/disks/pc/dos/ibm/2.00/manifest.xml
+++ b/disks/pc/dos/ibm/2.00/manifest.xml
@@ -7,10 +7,10 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 2.00 (Disk 1)
-
+
PC-DOS 2.00 (Disk 2)
diff --git a/disks/pc/dos/ibm/2.10/manifest.xml b/disks/pc/dos/ibm/2.10/manifest.xml
index d1a12fc0f..12ada6878 100644
--- a/disks/pc/dos/ibm/2.10/manifest.xml
+++ b/disks/pc/dos/ibm/2.10/manifest.xml
@@ -7,10 +7,10 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 2.10 (Disk 1)
-
+
PC-DOS 2.10 (Disk 2)
diff --git a/disks/pc/dos/ibm/3.00/manifest.xml b/disks/pc/dos/ibm/3.00/manifest.xml
index 4cd659ca3..945d8eeb4 100644
--- a/disks/pc/dos/ibm/3.00/manifest.xml
+++ b/disks/pc/dos/ibm/3.00/manifest.xml
@@ -7,10 +7,10 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 3.00 (Disk 1)
-
+
PC-DOS 3.00 (Disk 2)
diff --git a/disks/pc/dos/ibm/3.10/manifest.xml b/disks/pc/dos/ibm/3.10/manifest.xml
index 22ff667ea..09c7c169b 100644
--- a/disks/pc/dos/ibm/3.10/manifest.xml
+++ b/disks/pc/dos/ibm/3.10/manifest.xml
@@ -7,10 +7,10 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 3.10 (Disk 1)
-
+
PC-DOS 3.10 (Disk 2)
diff --git a/disks/pc/dos/ibm/3.20/manifest.xml b/disks/pc/dos/ibm/3.20/manifest.xml
index f1d6e7367..3fa617939 100644
--- a/disks/pc/dos/ibm/3.20/manifest.xml
+++ b/disks/pc/dos/ibm/3.20/manifest.xml
@@ -7,10 +7,10 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 3.20 (Disk 1)
-
+
PC-DOS 3.20 (Disk 2)
diff --git a/disks/pc/dos/ibm/3.30/manifest.xml b/disks/pc/dos/ibm/3.30/manifest.xml
index 988db1e5a..c1c3290e1 100644
--- a/disks/pc/dos/ibm/3.30/manifest.xml
+++ b/disks/pc/dos/ibm/3.30/manifest.xml
@@ -7,13 +7,13 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 3.30 (Disk 1)
-
+
PC-DOS 3.30 (Disk 2)
-
+
PC-DOS 3.30 (720K Disk)
diff --git a/disks/pc/dos/ibm/4.00/manifest.xml b/disks/pc/dos/ibm/4.00/manifest.xml
index 57730d536..726c0d1a7 100644
--- a/disks/pc/dos/ibm/4.00/manifest.xml
+++ b/disks/pc/dos/ibm/4.00/manifest.xml
@@ -7,19 +7,19 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 4.00 (Disk 1)
-
+
PC-DOS 4.00 (Disk 2)
-
+
PC-DOS 4.00 (Disk 3)
-
+
PC-DOS 4.00 (Disk 4)
-
+
PC-DOS 4.00 (Disk 5)
diff --git a/disks/pc/dos/ibm/5.00/manifest.xml b/disks/pc/dos/ibm/5.00/manifest.xml
index 6f084cbf7..ca826ad98 100644
--- a/disks/pc/dos/ibm/5.00/manifest.xml
+++ b/disks/pc/dos/ibm/5.00/manifest.xml
@@ -7,13 +7,13 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 5.00 (Disk 1)
-
+
PC-DOS 5.00 (Disk 2)
-
+
PC-DOS 5.00 (Disk 3)
diff --git a/disks/pc/dos/ibm/6.10/manifest.xml b/disks/pc/dos/ibm/6.10/manifest.xml
index 625bf6109..a21bcad41 100644
--- a/disks/pc/dos/ibm/6.10/manifest.xml
+++ b/disks/pc/dos/ibm/6.10/manifest.xml
@@ -7,19 +7,19 @@
Operating System
IBM/Microsoft
-
+
PC-DOS 6.10 (Disk 1)
-
+
PC-DOS 6.10 (Disk 2)
-
+
PC-DOS 6.10 (Disk 3)
-
+
PC-DOS 6.10 (Disk 4)
-
+
PC-DOS 6.10 (Disk 5)
diff --git a/disks/pc/dos/ibm/7.00/manifest.xml b/disks/pc/dos/ibm/7.00/manifest.xml
index 1386675da..01d101c1f 100644
--- a/disks/pc/dos/ibm/7.00/manifest.xml
+++ b/disks/pc/dos/ibm/7.00/manifest.xml
@@ -6,25 +6,25 @@
DOS
Operating System
IBM
-
+
PC-DOS 7.00 (SETUP Disk 1)
-
+
PC-DOS 7.00 (SETUP Disk 2)
-
+
PC-DOS 7.00 (SETUP Disk 3)
-
+
PC-DOS 7.00 (SETUP Disk 4)
-
+
PC-DOS 7.00 (SETUP Disk 5)
-
+
PC-DOS 7.00 (1.2M Disk)
-
+
PC-DOS 7.00 (1.44M Disk)
diff --git a/disks/pc/dos/microsoft/3.20/manifest.xml b/disks/pc/dos/microsoft/3.20/manifest.xml
index da5febac3..c5cc4f8b5 100644
--- a/disks/pc/dos/microsoft/3.20/manifest.xml
+++ b/disks/pc/dos/microsoft/3.20/manifest.xml
@@ -7,16 +7,16 @@
Operating System
Microsoft
July 7, 1986
-
+
MS-DOS 3.20 (Disk 1)
-
+
MS-DOS 3.20 (Disk 2)
-
+
MS-DOS 3.20 (ProgRef 1)
-
+
MS-DOS 3.20 (ProgRef 2)
diff --git a/disks/pc/dos/microsoft/3.21/manifest.xml b/disks/pc/dos/microsoft/3.21/manifest.xml
index 9a128fa41..9e5255d1f 100644
--- a/disks/pc/dos/microsoft/3.21/manifest.xml
+++ b/disks/pc/dos/microsoft/3.21/manifest.xml
@@ -7,10 +7,10 @@
Operating System
Microsoft
May 1, 1987
-
+
MS-DOS 3.21 (Disk 1)
-
+
MS-DOS 3.21 (Disk 2)
diff --git a/disks/pc/dos/microsoft/3.30/manifest.xml b/disks/pc/dos/microsoft/3.30/manifest.xml
index 42fa268c0..23e9bff06 100644
--- a/disks/pc/dos/microsoft/3.30/manifest.xml
+++ b/disks/pc/dos/microsoft/3.30/manifest.xml
@@ -7,11 +7,11 @@
Operating System
Microsoft
-
+
MS-DOS 3.30 (Disk 1)
-
+
MS-DOS 3.30 (Disk 2)
diff --git a/disks/pc/dos/microsoft/3.31/manifest.xml b/disks/pc/dos/microsoft/3.31/manifest.xml
index a28dae72d..d8140a380 100644
--- a/disks/pc/dos/microsoft/3.31/manifest.xml
+++ b/disks/pc/dos/microsoft/3.31/manifest.xml
@@ -7,7 +7,7 @@
Operating System
Microsoft
-
+
MS-DOS 3.31 (1440K Disk)
diff --git a/disks/pc/dos/microsoft/4.00/manifest.xml b/disks/pc/dos/microsoft/4.00/manifest.xml
index 015917f9e..cc732f395 100644
--- a/disks/pc/dos/microsoft/4.00/manifest.xml
+++ b/disks/pc/dos/microsoft/4.00/manifest.xml
@@ -7,22 +7,22 @@
Operating System
Microsoft
October 1988
-
+
MS-DOS 4.00 (Disk 1)
-
+
MS-DOS 4.00 (Disk 2)
-
+
MS-DOS 4.00 (Disk 3)
-
+
MS-DOS 4.00 (Disk 4)
-
+
MS-DOS 4.00 (Disk 5)
-
+
MS-DOS 4.00 (Disk 6)
diff --git a/disks/pc/dos/microsoft/4.01/720K/manifest.xml b/disks/pc/dos/microsoft/4.01/720K/manifest.xml
index 8f34563fa..cb7b55cd7 100644
--- a/disks/pc/dos/microsoft/4.01/720K/manifest.xml
+++ b/disks/pc/dos/microsoft/4.01/720K/manifest.xml
@@ -7,13 +7,13 @@
Operating System
Microsoft
April 1989
-
+
MS-DOS 4.01 (Disk 1)
-
+
MS-DOS 4.01 (Disk 2)
-
+
MS-DOS 4.01 (Disk 3)
diff --git a/disks/pc/dos/microsoft/4.01/manifest.xml b/disks/pc/dos/microsoft/4.01/manifest.xml
index 39b8866d4..81f11bdc6 100644
--- a/disks/pc/dos/microsoft/4.01/manifest.xml
+++ b/disks/pc/dos/microsoft/4.01/manifest.xml
@@ -8,22 +8,22 @@
Microsoft
April 1989
-
+
MS-DOS 4.01 (Disk 1)
-
+
MS-DOS 4.01 (Disk 2)
-
+
MS-DOS 4.01 (Disk 3)
-
+
MS-DOS 4.01 (Disk 4)
-
+
MS-DOS 4.01 (Disk 5)
-
+
MS-DOS 4.01 (Disk 6)
diff --git a/disks/pc/dos/microsoft/5.00/manifest.xml b/disks/pc/dos/microsoft/5.00/manifest.xml
index 813a9e123..d835b868e 100644
--- a/disks/pc/dos/microsoft/5.00/manifest.xml
+++ b/disks/pc/dos/microsoft/5.00/manifest.xml
@@ -7,28 +7,28 @@
Operating System
Microsoft
-
+
MS-DOS 5.00 (360K Disk 1)
-
+
MS-DOS 5.00 (360K Disk 2)
-
+
MS-DOS 5.00 (360K Disk 3)
-
+
MS-DOS 5.00 (360K Disk 4)
-
+
MS-DOS 5.00 (360K Disk 5)
-
+
MS-DOS 5.00 (720K Disk 1)
-
+
MS-DOS 5.00 (720K Disk 2)
-
+
MS-DOS 5.00 (720K Disk 3)
diff --git a/disks/pc/dos/microsoft/6.00/manifest.xml b/disks/pc/dos/microsoft/6.00/manifest.xml
index 9d3e1534d..bb8b47a86 100644
--- a/disks/pc/dos/microsoft/6.00/manifest.xml
+++ b/disks/pc/dos/microsoft/6.00/manifest.xml
@@ -7,25 +7,25 @@
Operating System
Microsoft
-
+
MS-DOS 6.00 (1200K Disk 1)
-
+
MS-DOS 6.00 (1200K Disk 2)
-
+
MS-DOS 6.00 (1200K Disk 3)
-
+
MS-DOS 6.00 (1200K Disk 4)
-
+
MS-DOS 6.00 (1440K Disk 1)
-
+
MS-DOS 6.00 (1440K Disk 1)
-
+
MS-DOS 6.00 (1440K Disk 1)
diff --git a/disks/pc/dos/microsoft/6.20/manifest.xml b/disks/pc/dos/microsoft/6.20/manifest.xml
index bd0232eeb..a390d2ad8 100644
--- a/disks/pc/dos/microsoft/6.20/manifest.xml
+++ b/disks/pc/dos/microsoft/6.20/manifest.xml
@@ -7,31 +7,31 @@
Operating System
Microsoft
-
+
MS-DOS 6.20 (1200K Disk 1)
-
+
MS-DOS 6.20 (1200K Disk 2)
-
+
MS-DOS 6.20 (1200K Disk 3)
-
+
MS-DOS 6.20 (1200K Disk 4)
-
+
MS-DOS 6.20 (1200K Supp Disk)
-
+
MS-DOS 6.20 (1440K Disk 1)
-
+
MS-DOS 6.20 (1440K Disk 2)
-
+
MS-DOS 6.20 (1440K Disk 3)
-
+
MS-DOS 6.20 (1440K Supp Disk)
diff --git a/disks/pc/dos/microsoft/6.22/manifest.xml b/disks/pc/dos/microsoft/6.22/manifest.xml
index 1fe31f05f..6f4d454cb 100644
--- a/disks/pc/dos/microsoft/6.22/manifest.xml
+++ b/disks/pc/dos/microsoft/6.22/manifest.xml
@@ -7,28 +7,28 @@
Operating System
Microsoft
-
+
MS-DOS 6.22 (1200K Disk 1)
-
+
MS-DOS 6.22 (1200K Disk 2)
-
+
MS-DOS 6.22 (1200K Disk 3)
-
+
MS-DOS 6.22 (1200K Disk 4)
-
+
MS-DOS 6.22 (1440K Disk 1)
-
+
MS-DOS 6.22 (1440K Disk 2)
-
+
MS-DOS 6.22 (1440K Disk 3)
-
+
MS-DOS 6.22 (1440K Supp Disk)
diff --git a/disks/pc/games/infocom/machine-debug.xml b/disks/pc/games/infocom/machine-debug.xml
index 5669d1d8c..a808d2ae3 100644
--- a/disks/pc/games/infocom/machine-debug.xml
+++ b/disks/pc/games/infocom/machine-debug.xml
@@ -5,8 +5,8 @@
-
-
+
+
ESC
diff --git a/disks/pc/games/microsoft/flightsim/manifest.xml b/disks/pc/games/microsoft/flightsim/manifest.xml
index 5bb4a3384..f4036d89c 100644
--- a/disks/pc/games/microsoft/flightsim/manifest.xml
+++ b/disks/pc/games/microsoft/flightsim/manifest.xml
@@ -7,7 +7,7 @@
Simulation
Microsoft
1984
-
+
MS Flight Simulator (1984)
FS.EXE
FS.HLP
diff --git a/disks/pc/minix/1.1/manifest.xml b/disks/pc/minix/1.1/manifest.xml
index 2de564518..2b77fb708 100644
--- a/disks/pc/minix/1.1/manifest.xml
+++ b/disks/pc/minix/1.1/manifest.xml
@@ -3,19 +3,19 @@
MINIX
1.1
-
+
Minix Boot (Disk 1)
-
+
Minix Root Filesystem (Disk 2)
-
+
Minix User Files (Disk 3)
-
+
Minix Kernel (Disk 4)
-
+
Minix Tools (Disk 5)
diff --git a/disks/pc/os2/ibm/1.0/manifest.xml b/disks/pc/os2/ibm/1.0/manifest.xml
index 3268ba7e0..947cf5101 100644
--- a/disks/pc/os2/ibm/1.0/manifest.xml
+++ b/disks/pc/os2/ibm/1.0/manifest.xml
@@ -3,16 +3,16 @@
IBM OS/2 1.0
-
+
IBM OS/2 1.0 (1.44M Install)
-
+
IBM OS/2 1.0 (1.44M Disk 1)
-
+
IBM OS/2 1.0 (1.44M Disk 2)
-
+
IBM OS/2 1.0 (1.44M Disk 3)
diff --git a/disks/pc/os2/ibm/1.1/manifest.xml b/disks/pc/os2/ibm/1.1/manifest.xml
index a2c53f96c..e9fa40de5 100644
--- a/disks/pc/os2/ibm/1.1/manifest.xml
+++ b/disks/pc/os2/ibm/1.1/manifest.xml
@@ -2,25 +2,25 @@
IBM OS/2 1.1
-
+
IBM OS/2 1.1 (1.44M Install Disk)
-
+
IBM OS/2 1.1 (1.44M Disk 1)
-
+
IBM OS/2 1.1 (1.44M Disk 2)
-
+
IBM OS/2 1.1 (1.44M Disk 3)
-
+
IBM OS/2 1.1 (1.44M Disk 4)
-
+
IBM OS/2 1.1 (1.44M Devices Disk)
-
+
IBM OS/2 1.1 (1.44M Printers Disk)
diff --git a/disks/pc/os2/ibm/1.3/manifest.xml b/disks/pc/os2/ibm/1.3/manifest.xml
index 15d68fdd1..20b20161b 100644
--- a/disks/pc/os2/ibm/1.3/manifest.xml
+++ b/disks/pc/os2/ibm/1.3/manifest.xml
@@ -2,34 +2,34 @@
IBM OS/2 1.3
-
+
IBM OS/2 1.3 (1.44M Disk 1)
-
+
IBM OS/2 1.3 (1.44M Disk 2)
-
+
IBM OS/2 1.3 (1.44M Disk 3)
-
+
IBM OS/2 1.3 (1.44M Disk 4)
-
+
IBM OS/2 1.3 (1.44M Disk 5)
-
+
IBM OS/2 1.3 (1.44M Disk 6)
-
+
IBM OS/2 1.3 (1.44M Disk 7)
-
+
IBM OS/2 1.3 (1.44M Disk 8)
-
+
IBM OS/2 1.3 (1.44M Disk 9)
-
+
IBM OS/2 1.3 (1.44M Disk 10)
diff --git a/disks/pc/os2/microsoft/1.0/manifest.xml b/disks/pc/os2/microsoft/1.0/manifest.xml
index 165a7e02a..2e7ce61c6 100644
--- a/disks/pc/os2/microsoft/1.0/manifest.xml
+++ b/disks/pc/os2/microsoft/1.0/manifest.xml
@@ -2,13 +2,13 @@
MS OS/2 1.0
-
+
MS OS/2 1.0 (1.2M Install)
-
+
MS OS/2 1.0 (1.2M Program)
-
+
MS OS/2 1.0 (1.2M Supplemental)
diff --git a/disks/pc/os2/misc/manifest.xml b/disks/pc/os2/misc/manifest.xml
index 95d36fd1a..02ad7624a 100644
--- a/disks/pc/os2/misc/manifest.xml
+++ b/disks/pc/os2/misc/manifest.xml
@@ -2,22 +2,22 @@
OS/2 Prototype Disks
-
+
OS/2 CP-DOS (v7.68)
-
+
OS/2 FOOTBALL (v7.68.17)
-
+
OS/2 FOOTBALL (v4.41.00)
-
+
OS/2 1.0 Debugger
-
+
OS/2 SIZZLE (v7.68.18)
-
+
OS/2 SIZZLE (v7.68.18 DEBUG)
diff --git a/disks/pc/tools/borland/pascal/3.00b/manifest.xml b/disks/pc/tools/borland/pascal/3.00b/manifest.xml
index 40ad2dffa..ce269676c 100644
--- a/disks/pc/tools/borland/pascal/3.00b/manifest.xml
+++ b/disks/pc/tools/borland/pascal/3.00b/manifest.xml
@@ -2,7 +2,7 @@
Borland Turbo Pascal
-
+
Borland Turbo Pascal 3.00B
diff --git a/disks/pc/tools/borland/pascal/3.01a/manifest.xml b/disks/pc/tools/borland/pascal/3.01a/manifest.xml
index fbacbbdc1..516320183 100644
--- a/disks/pc/tools/borland/pascal/3.01a/manifest.xml
+++ b/disks/pc/tools/borland/pascal/3.01a/manifest.xml
@@ -2,7 +2,7 @@
Borland Turbo Pascal
-
+
Borland Turbo Pascal 3.01A
diff --git a/disks/pc/tools/microsoft/basic/manifest.xml b/disks/pc/tools/microsoft/basic/manifest.xml
index c77abe3c4..c2e2316ed 100644
--- a/disks/pc/tools/microsoft/basic/manifest.xml
+++ b/disks/pc/tools/microsoft/basic/manifest.xml
@@ -7,10 +7,10 @@
BASIC Compiler
Microsoft
-
+
MS BASIC (Compiler v5.36)
-
+
MS BASIC (QuickBASIC v2.0)
diff --git a/disks/pc/tools/microsoft/c/4.00/manifest.xml b/disks/pc/tools/microsoft/c/4.00/manifest.xml
index f86e0cee0..bb3bbcc3f 100644
--- a/disks/pc/tools/microsoft/c/4.00/manifest.xml
+++ b/disks/pc/tools/microsoft/c/4.00/manifest.xml
@@ -7,28 +7,28 @@
C Compiler
Microsoft
-
+
MS C 4.00 (Disk 1)Compiler
-
+
MS C 4.00 (Disk 2)Utilities
-
+
MS C 4.00 (Disk 3)Small-Model Libs
-
+
MS C 4.00 (Disk 4)Medium-Model Libs
-
+
MS C 4.00 (Disk 5)Large-Model Libs
-
+
MS C 4.00 (Disk 6)Startup Source Code
-
+
MS C 4.00 (Disk 7)Learning CodeView
-
+
MS C 4.00 (Disk 8)Windows DevKit Update
diff --git a/disks/pc/tools/microsoft/masm/4.00/manifest.xml b/disks/pc/tools/microsoft/masm/4.00/manifest.xml
index 90bc69edb..df1af4ed2 100644
--- a/disks/pc/tools/microsoft/masm/4.00/manifest.xml
+++ b/disks/pc/tools/microsoft/masm/4.00/manifest.xml
@@ -6,7 +6,7 @@
Assembler
Microsoft
-
+
MS MASM 4.00
diff --git a/disks/pc/tools/microsoft/mouse/5.00/manifest.xml b/disks/pc/tools/microsoft/mouse/5.00/manifest.xml
index 9eb2a0549..b8ecf0365 100644
--- a/disks/pc/tools/microsoft/mouse/5.00/manifest.xml
+++ b/disks/pc/tools/microsoft/mouse/5.00/manifest.xml
@@ -7,10 +7,10 @@
Mouse Driver
Microsoft
-
+
MS Mouse 5.00 (System)
-
+
MS Mouse 5.00 (Program)
diff --git a/disks/pc/tools/microsoft/os2/sdk/1.02/manifest.xml b/disks/pc/tools/microsoft/os2/sdk/1.02/manifest.xml
index 7a1405adc..a7910192c 100644
--- a/disks/pc/tools/microsoft/os2/sdk/1.02/manifest.xml
+++ b/disks/pc/tools/microsoft/os2/sdk/1.02/manifest.xml
@@ -2,40 +2,40 @@
MS OS/2 SDK 1.02
-
+
MS OS/2 SDK 1.02: TOOLKIT1
-
+
MS OS/2 SDK 1.02: TOOLKIT2
-
+
MS OS/2 SDK 1.02: UTILITY1
-
+
MS OS/2 SDK 1.02: UTILITY2
-
+
MS OS/2 SDK 1.02: CBIN1
-
+
MS OS/2 SDK 1.02: CBIN2
-
+
MS OS/2 SDK 1.02: CLIB1
-
+
MS OS/2 SDK 1.02: CLIB2
-
+
MS OS/2 SDK 1.02: MASM
-
+
MS OS/2 SDK 1.02: EXAMPLE1
-
+
MS OS/2 SDK 1.02: EXAMPLE2
-
+
MS OS/2 SDK 1.02: NETWORK
diff --git a/disks/pc/tools/microsoft/windows/sdk/1.01/manifest.xml b/disks/pc/tools/microsoft/windows/sdk/1.01/manifest.xml
index 0c4a7d542..2437b4241 100644
--- a/disks/pc/tools/microsoft/windows/sdk/1.01/manifest.xml
+++ b/disks/pc/tools/microsoft/windows/sdk/1.01/manifest.xml
@@ -2,40 +2,40 @@
Windows 1.01 SDK
-
+
Win101 Runtime (SETUP)
-
+
Win101 Runtime (BUILD)
-
+
Win101 Runtime (UTILITIES)
-
+
Win101 Runtime (SAMPLES)
-
+
Win101 SDK (UTILITIES)
-
+
Win101 SDK (LIB SMALL)
-
+
Win101 SDK (LIB MEDIUM)
-
+
Win101 SDK (LIB LARGE)
-
+
Win101 SDK (LIB PASCAL)
-
+
Win101 SDK (INC PIC)
-
+
Win101 SDK (SAMPLES)
-
+
Win101 SDK (C UPDATE)
diff --git a/disks/pc/tools/microsoft/windows/sdk/1.03/manifest.xml b/disks/pc/tools/microsoft/windows/sdk/1.03/manifest.xml
index 46f7079ff..41c6e6020 100644
--- a/disks/pc/tools/microsoft/windows/sdk/1.03/manifest.xml
+++ b/disks/pc/tools/microsoft/windows/sdk/1.03/manifest.xml
@@ -2,25 +2,25 @@
Windows 1.03 SDK
-
+
Win103 SDK (UTIL1)
-
+
Win103 SDK (UTIL2)
-
+
Win103 SDK (LIB C)
-
+
Win103 SDK (LIB PASCAL)
-
+
Win103 SDK (SYMBOLS)
-
+
Win103 SDK (SAMPLE1)
-
+
Win103 SDK (SAMPLE2)
diff --git a/disks/pc/tools/microsoft/windows/sdk/1.04/manifest.xml b/disks/pc/tools/microsoft/windows/sdk/1.04/manifest.xml
index 44767e520..80c301529 100644
--- a/disks/pc/tools/microsoft/windows/sdk/1.04/manifest.xml
+++ b/disks/pc/tools/microsoft/windows/sdk/1.04/manifest.xml
@@ -3,25 +3,25 @@
Windows 1.04 SDK
os2museum.com
-
+
Win104 SDK (UTIL 1)
-
+
Win104 SDK (UTIL 2)
-
+
Win104 SDK (LIB C)
-
+
Win104 SDK (LIB PASCAL)
-
+
Win104 SDK (SYMBOLS)
-
+
Win104 SDK (SAMPLE1)
-
+
Win104 SDK (SAMPLE2)
diff --git a/disks/pc/tools/microsoft/windows/sdk/2.03/manifest.xml b/disks/pc/tools/microsoft/windows/sdk/2.03/manifest.xml
index 30bd33088..9b4417408 100644
--- a/disks/pc/tools/microsoft/windows/sdk/2.03/manifest.xml
+++ b/disks/pc/tools/microsoft/windows/sdk/2.03/manifest.xml
@@ -3,13 +3,13 @@
Windows 2.03 SDK
os2museum.com
-
+
Win203 SDK (1200K Disk 1)
-
+
Win203 SDK (1200K Disk 2)
-
+
Win203 SDK (1200K Disk 3)
diff --git a/disks/pc/tools/microsoft/windows/sdk/3.00/manifest.xml b/disks/pc/tools/microsoft/windows/sdk/3.00/manifest.xml
index b2d605c5e..9ab806544 100644
--- a/disks/pc/tools/microsoft/windows/sdk/3.00/manifest.xml
+++ b/disks/pc/tools/microsoft/windows/sdk/3.00/manifest.xml
@@ -2,43 +2,43 @@
Windows 3.0 SDK
-
+
Win300 SDK (720K Disk 1)
Development Tools 1 (For DOS Systems) Version 3.0
-
+
Win300 SDK (720K Disk 2)
Development Tools 2/Debug Tools 1
-
+
Win300 SDK (720K Disk 3)
Debug Tools 2/Debug Files 1
-
+
Win300 SDK (720K Disk 4)
Debug Files 2
-
+
Win300 SDK (720K Disk 5)
Link Libraries 1
-
+
Win300 SDK (720K Disk 6)
Link Libraries 2
-
+
Win300 SDK (720K Disk 7)
Include Files/Sample Source Code 1
-
+
Win300 SDK (720K Disk 8)
Sample Source Code 2
-
+
Win300 SDK (720K Disk 9)
Online Reference (Advisor Format)
-
+
Win300 SDK (720K Disk 10)
Online Reference (Windows Help Format)
diff --git a/disks/pc/unix/ibm/pcix/1.0/manifest.xml b/disks/pc/unix/ibm/pcix/1.0/manifest.xml
index 611dd0b46..f2d95fb37 100644
--- a/disks/pc/unix/ibm/pcix/1.0/manifest.xml
+++ b/disks/pc/unix/ibm/pcix/1.0/manifest.xml
@@ -2,61 +2,61 @@
PC/IX 1.0
-
+
PC/IX 1.0 (MAINT)
-
+
PC/IX 1.0 (CORE1)
-
+
PC/IX 1.0 (CORE2)
-
+
PC/IX 1.0 (CORE3)
-
+
PC/IX 1.0 (CORE4)
-
+
PC/IX 1.0 (CORE5)
-
+
PC/IX 1.0 (CORE6)
-
+
PC/IX 1.0 (CORE7)
-
+
PC/IX 1.0 (CORE8)
-
+
PC/IX 1.0 (PROG1)
-
+
PC/IX 1.0 (PROG2)
-
+
PC/IX 1.0 (PROG3)
-
+
PC/IX 1.0 (PROG4)
-
+
PC/IX 1.0 (COMMS)
-
+
PC/IX 1.0 (SCCS)
-
+
PC/IX 1.0 (TEXT)
-
+
PC/IX 1.0 (SPECIA)
-
+
PC/IX 1.0 (GAMES)
-
+
PC/IX 1.0 (ACCNT)
diff --git a/disks/pc/unix/microport/system-v/2.3/manifest.xml b/disks/pc/unix/microport/system-v/2.3/manifest.xml
index 8aad69d9e..2ff1927ec 100644
--- a/disks/pc/unix/microport/system-v/2.3/manifest.xml
+++ b/disks/pc/unix/microport/system-v/2.3/manifest.xml
@@ -2,49 +2,49 @@
Microport's AT&T UNIX System V-AT 2.3 (5¨)
-
+
Boot Disk
-
+
Runtime Disk 1
-
+
Runtime Disk 2
-
+
Runtime Disk 3
-
+
Runtime Utility Disk
-
+
Runtime System Vision
-
+
Runtime Link Kit Disk
-
+
Software Dev Disk 1
-
+
Software Dev Disk 2
-
+
Software Dev Disk 3
-
+
Software Dev Disk 4
-
+
Software Dev Upgrade
-
+
Text Prep Disk 1
-
+
Text Prep Disk 2
-
+
Text Prep Disk 3
diff --git a/disks/pc/windows/1.00/manifest.xml b/disks/pc/windows/1.00/manifest.xml
index ae7ff291c..ea6e84d5e 100644
--- a/disks/pc/windows/1.00/manifest.xml
+++ b/disks/pc/windows/1.00/manifest.xml
@@ -2,16 +2,16 @@
Microsoft Windows 1.00
-
+
Windows 1.00 (SETUP)
-
+
Windows 1.00 (BUILD)
-
+
Windows 1.00 (UTILITY)
-
+
Windows 1.00 (APPS)
diff --git a/disks/pc/windows/1.01/manifest.xml b/disks/pc/windows/1.01/manifest.xml
index f74f30f2f..0340bb706 100644
--- a/disks/pc/windows/1.01/manifest.xml
+++ b/disks/pc/windows/1.01/manifest.xml
@@ -3,7 +3,7 @@
Microsoft Windows 1.01
-
+
Windows 1.01 (SETUP)
CGA.DRV
COMM.DRV
@@ -33,7 +33,7 @@
SYSTEM.DRV
WRITE.DAT
-
+
Windows 1.01 (BUILD)
BUILD.LBL
CGA.GRB
@@ -57,7 +57,7 @@
WIN.INI
WINOLDAP.MOD
-
+
Windows 1.01 (UTILITY)
CITOH.DRV
COURA.FON
@@ -89,7 +89,7 @@
TOSH.DRV
UTILITY.LBL
-
+
Windows 1.01 (APPS)
ABC.TXT
CALC.EXE
@@ -104,7 +104,7 @@
REVERSI.EXE
TERMINAL.EXE
-
+
Windows 1.01 (WRITE)
PRACTICE.DOC
README.DOC
diff --git a/disks/pc/windows/1.02/manifest.xml b/disks/pc/windows/1.02/manifest.xml
index 7970e041b..599c17c56 100644
--- a/disks/pc/windows/1.02/manifest.xml
+++ b/disks/pc/windows/1.02/manifest.xml
@@ -2,22 +2,22 @@
Microsoft Windows 1.02
-
+
Windows 1.02 (SETUP)
-
+
Windows 1.02 (BUILD)
-
+
Windows 1.02 (UTILITY)
-
+
Windows 1.02 (FONT)
-
+
Windows 1.02 (APPS)
-
+
Windows 1.02 (WRITE)
diff --git a/disks/pc/windows/1.03/manifest.xml b/disks/pc/windows/1.03/manifest.xml
index 10cbcf0ed..01ee9b28f 100644
--- a/disks/pc/windows/1.03/manifest.xml
+++ b/disks/pc/windows/1.03/manifest.xml
@@ -2,22 +2,22 @@
Microsoft Windows 1.03
-
+
Windows 1.03 (SETUP)
-
+
Windows 1.03 (BUILD)
-
+
Windows 1.03 (UTILITY)
-
+
Windows 1.03 (FONT)
-
+
Windows 1.03 (APPS)
-
+
Windows 1.03 (PROGRAM)
diff --git a/disks/pc/windows/1.03a/manifest.xml b/disks/pc/windows/1.03a/manifest.xml
index a80fdf2d4..5b4fd80fc 100644
--- a/disks/pc/windows/1.03a/manifest.xml
+++ b/disks/pc/windows/1.03a/manifest.xml
@@ -2,28 +2,28 @@
Microsoft Windows 1.03a
-
+
Windows 1.03a (SETUP)
-
+
Windows 1.03a (BUILD)
-
+
Windows 1.03a (UTILITY)
-
+
Windows 1.03a (FONT)
-
+
Windows 1.03a (APPS)
-
+
Windows 1.03a (PROGRAM)
-
+
Windows 1.03a (SYMBOLS A)
-
+
Windows 1.03a (SYMBOLS B)
diff --git a/disks/pc/windows/1.03b/manifest.xml b/disks/pc/windows/1.03b/manifest.xml
index 28e4a156d..1080dc531 100644
--- a/disks/pc/windows/1.03b/manifest.xml
+++ b/disks/pc/windows/1.03b/manifest.xml
@@ -2,22 +2,22 @@
Microsoft Windows 1.03b
-
+
Windows 1.03b (SETUP)
-
+
Windows 1.03b (BUILD)
-
+
Windows 1.03b (UTILITY)
-
+
Windows 1.03b (FONT)
-
+
Windows 1.03b (APPS)
-
+
Windows 1.03b (PROGRAM)
diff --git a/disks/pc/windows/1.04/manifest.xml b/disks/pc/windows/1.04/manifest.xml
index 5c693ff41..4bb61a697 100644
--- a/disks/pc/windows/1.04/manifest.xml
+++ b/disks/pc/windows/1.04/manifest.xml
@@ -3,25 +3,25 @@
Microsoft Windows 1.04
os2museum.com
-
+
Windows 1.04 (SETUP)
-
+
Windows 1.04 (BUILD)
-
+
Windows 1.04 (UTILITY)
-
+
Windows 1.04 (FONT)
-
+
Windows 1.04 (APPS)
-
+
Windows 1.04 (PROGRAM)
-
+
Windows 1.04 (SUPP)
diff --git a/disks/pc/windows/2.01/manifest.xml b/disks/pc/windows/2.01/manifest.xml
index d4f88685a..28e2b500b 100644
--- a/disks/pc/windows/2.01/manifest.xml
+++ b/disks/pc/windows/2.01/manifest.xml
@@ -2,13 +2,13 @@
Microsoft Windows/386 2.01
-
+
Windows/386 2.01 (Disk 1)
-
+
Windows/386 2.01 (Disk 2)
-
+
Windows/386 2.01 (Disk 3)
diff --git a/disks/pc/windows/2.03/manifest.xml b/disks/pc/windows/2.03/manifest.xml
index 6fdca31a5..15c59ba78 100644
--- a/disks/pc/windows/2.03/manifest.xml
+++ b/disks/pc/windows/2.03/manifest.xml
@@ -3,46 +3,46 @@
Microsoft Windows 2.03
os2museum.com
-
+
Windows 2.03 (SETUP)
-
+
Windows 2.03 (BUILD)
-
+
Windows 2.03 (DISPLAYS)
-
+
Windows 2.03 (UTILS 1)
-
+
Windows 2.03 (UTILS 2)
-
+
Windows 2.03 (FONTS 1)
-
+
Windows 2.03 (FONTS 2)
-
+
Windows 2.03 (APPS)
-
+
Windows 2.03 (PROGRAM)
-
+
Windows/386 2.03 (SETUP)
-
+
Windows/386 2.03 (UTILITY)
-
+
Windows/386 2.03 (FONTS)
-
+
Windows/386 2.03 (PROGRAM)
-
+
Windows/386 2.03 (UTILITY 2)
diff --git a/disks/pc/windows/2.10/manifest.xml b/disks/pc/windows/2.10/manifest.xml
index 3efb59a05..04934a154 100644
--- a/disks/pc/windows/2.10/manifest.xml
+++ b/disks/pc/windows/2.10/manifest.xml
@@ -2,22 +2,22 @@
Microsoft Windows/386 2.10
-
+
Windows/386 2.10 (SETUP)
-
+
Windows/386 2.10 (UTILS 1)
-
+
Windows/386 2.10 (UTILS 2)
-
+
Windows/386 2.10 (DISPLAYS)
-
+
Windows/386 2.10 (FONTS)
-
+
Windows/386 2.10 (APPS)
diff --git a/disks/pc/windows/2.11/manifest.xml b/disks/pc/windows/2.11/manifest.xml
index ea7863aba..593d10c74 100644
--- a/disks/pc/windows/2.11/manifest.xml
+++ b/disks/pc/windows/2.11/manifest.xml
@@ -2,28 +2,28 @@
Microsoft Windows 2.11
-
+
Windows/286 2.11 (SETUP)
-
+
Windows/286 2.11 (UTIL 1)
-
+
Windows/286 2.11 (UTIL 2)
-
+
Windows/286 2.11 (APPS)
-
+
Windows/386 2.11 (SETUP)
-
+
Windows/386 2.11 (UTIL 1)
-
+
Windows/386 2.11 (UTIL 2)
-
+
Windows/386 2.11 (APPS)
diff --git a/disks/pc/windows/3.00/720K/manifest.xml b/disks/pc/windows/3.00/720K/manifest.xml
index 64dfd75b4..bac9289da 100644
--- a/disks/pc/windows/3.00/720K/manifest.xml
+++ b/disks/pc/windows/3.00/720K/manifest.xml
@@ -2,25 +2,25 @@
Microsoft Windows 3.00
-
+
Windows 3.00 (720K Disk 1)
-
+
Windows 3.00 (720K Disk 2)
-
+
Windows 3.00 (720K Disk 3)
-
+
Windows 3.00 (720K Disk 4)
-
+
Windows 3.00 (720K Disk 5)
-
+
Windows 3.00 (720K Disk 6)
-
+
Windows 3.00 (720K Disk 7)
diff --git a/disks/pc/windows/3.00/manifest.xml b/disks/pc/windows/3.00/manifest.xml
index 6f6b00507..3f66a8abc 100644
--- a/disks/pc/windows/3.00/manifest.xml
+++ b/disks/pc/windows/3.00/manifest.xml
@@ -2,19 +2,19 @@
Microsoft Windows 3.00
-
+
Windows 3.00 (Disk 1)
-
+
Windows 3.00 (Disk 2)
-
+
Windows 3.00 (Disk 3)
-
+
Windows 3.00 (Disk 4)
-
+
Windows 3.00 (Disk 5)
diff --git a/disks/pc/windows/3.10/manifest.xml b/disks/pc/windows/3.10/manifest.xml
index a0502c6be..8de28daa1 100644
--- a/disks/pc/windows/3.10/manifest.xml
+++ b/disks/pc/windows/3.10/manifest.xml
@@ -2,25 +2,25 @@
Microsoft Windows 3.10
-
+
Windows 3.10 (Disk 1)
-
+
Windows 3.10 (Disk 2)
-
+
Windows 3.10 (Disk 3)
-
+
Windows 3.10 (Disk 4)
-
+
Windows 3.10 (Disk 5)
-
+
Windows 3.10 (Disk 6)
-
+
Windows 3.10 (Disk 7)
diff --git a/disks/pc/windows/3.11/manifest.xml b/disks/pc/windows/3.11/manifest.xml
index 468232979..c8993a6a0 100644
--- a/disks/pc/windows/3.11/manifest.xml
+++ b/disks/pc/windows/3.11/manifest.xml
@@ -7,28 +7,28 @@
Operating System
Microsoft
-
+
Windows 3.11 (Disk 1)
-
+
Windows 3.11 (Disk 2)
-
+
Windows 3.11 (Disk 3)
-
+
Windows 3.11 (Disk 4)
-
+
Windows 3.11 (Disk 5)
-
+
Windows 3.11 (Disk 6)
-
+
Windows 3.11 (Disk 7)
-
+
Windows 3.11 (Disk 8)
diff --git a/disks/pc/windows/win95/4.00.499/manifest.xml b/disks/pc/windows/win95/4.00.499/manifest.xml
index c108141d0..5f6c5723f 100644
--- a/disks/pc/windows/win95/4.00.499/manifest.xml
+++ b/disks/pc/windows/win95/4.00.499/manifest.xml
@@ -2,43 +2,43 @@
Windows 95 (Build 499)
-
+
Windows 95 (Build 499 Disk 1)
-
+
Windows 95 (Build 499 Disk 2)
-
+
Windows 95 (Build 499 Disk 3)
-
+
Windows 95 (Build 499 Disk 4)
-
+
Windows 95 (Build 499 Disk 5)
-
+
Windows 95 (Build 499 Disk 6)
-
+
Windows 95 (Build 499 Disk 7)
-
+
Windows 95 (Build 499 Disk 8)
-
+
Windows 95 (Build 499 Disk 9)
-
+
Windows 95 (Build 499 Disk 10)
-
+
Windows 95 (Build 499 Disk 11)
-
+
Windows 95 (Build 499 Disk 12)
-
+
Windows 95 (Build 499 Disk 13)
diff --git a/disks/pc/windows/win95/4.00.950/manifest.xml b/disks/pc/windows/win95/4.00.950/manifest.xml
index 7cdfeff96..308f9c465 100644
--- a/disks/pc/windows/win95/4.00.950/manifest.xml
+++ b/disks/pc/windows/win95/4.00.950/manifest.xml
@@ -7,46 +7,46 @@
Operating System
Microsoft
August 24, 1995
-
+
Windows 95 (Boot)
-
+
Windows 95 (Disk 1)
-
+
Windows 95 (Disk 2)
-
+
Windows 95 (Disk 3)
-
+
Windows 95 (Disk 4)
-
+
Windows 95 (Disk 5)
-
+
Windows 95 (Disk 6)
-
+
Windows 95 (Disk 7)
-
+
Windows 95 (Disk 8)
-
+
Windows 95 (Disk 9)
-
+
Windows 95 (Disk 10)
-
+
Windows 95 (Disk 11)
-
+
Windows 95 (Disk 12)
-
+
Windows 95 (Disk 13)
diff --git a/disks/pc/windows/wincomm/manifest.xml b/disks/pc/windows/wincomm/manifest.xml
index 1fa1f33b5..7e7161754 100644
--- a/disks/pc/windows/wincomm/manifest.xml
+++ b/disks/pc/windows/wincomm/manifest.xml
@@ -2,7 +2,7 @@
Windows COMM Driver (Source)
-
+
WINCOMM
diff --git a/disks/pc/xenix/sco/8086/2.1.3/manifest.xml b/disks/pc/xenix/sco/8086/2.1.3/manifest.xml
index 68f44ffce..10572d1bc 100644
--- a/disks/pc/xenix/sco/8086/2.1.3/manifest.xml
+++ b/disks/pc/xenix/sco/8086/2.1.3/manifest.xml
@@ -2,52 +2,52 @@
SCO Xenix 8086 Operating System v2.1.3
-
+
SCO Xenix 8086 (N1)
-
+
SCO Xenix 8086 (N2)
-
+
SCO Xenix 8086 (N3)
-
+
SCO Xenix 8086 (N4)
-
+
SCO Xenix 8086 (N5)
-
+
SCO Xenix 8086 (N6)
-
+
SCO Xenix 8086 (B1)
-
+
SCO Xenix 8086 (B2)
-
+
SCO Xenix 8086 (B3)
-
+
SCO Xenix 8086 (X1)
-
+
SCO Xenix 8086 (X2)
-
+
SCO Xenix 8086 (X3)
-
+
SCO Xenix 8086 (X4)
-
+
SCO Xenix 8086 (X5)
-
+
SCO Xenix 8086 (X6)
-
+
SCO Xenix 8086 (GAMES)
diff --git a/modules/htmlout/lib/htmlout.js b/modules/htmlout/lib/htmlout.js
index 42eeb0d60..8b006ab55 100644
--- a/modules/htmlout/lib/htmlout.js
+++ b/modules/htmlout/lib/htmlout.js
@@ -1587,7 +1587,7 @@ HTMLOut.prototype.getManifestXML = function(sToken, sIndent, aParms)
var matchCover = null;
match = matchNode[2].match(']*href="([^"]*)"');
- if (match && match[1].indexOf("static/") >= 0) {
+ if (match && match[1].indexOf("archive/") >= 0) {
matchCover = match[1];
if (obj.fDebug) {
sNodeLink = matchCover.replace("/thumbs/", '/').replace(/ ?[0-9]*\.(jpeg|jpg)/, ".pdf");
diff --git a/modules/shared/lib/netlib.js b/modules/shared/lib/netlib.js
index bd5fe2b63..1815bb74e 100644
--- a/modules/shared/lib/netlib.js
+++ b/modules/shared/lib/netlib.js
@@ -140,7 +140,7 @@ net.propagateParms = function(sURL, req)
* Used to encodes any URLs presented on the current page, using this 3-step (um, 4-step) process:
*
* 1) Replace any backslashes with slashes, in case the URL was derived from a file system path
- * 2) Remap links that begin with "static/" to the corresponding URL at "http://static.pcjs.org/"
+ * 2) Remap links that begin with "archive/" to the corresponding URL at "http://archive.pcjs.org/"
* 3) Transform any "htmlspecialchars" into the corresponding entities, using encodeURI()
* 4) Massage the result with net.propagateParms(), so that any special parameters are passed along
*
@@ -154,9 +154,9 @@ net.encodeURL = function(sURL, req, fDebug)
if (sURL) {
sURL = sURL.replace(/\\/g, '/');
if (!fDebug) {
- if (sURL.match(/^[^:?]*static\//)) {
+ if (sURL.match(/^[^:?]*archive\//)) {
if (sURL.charAt(0) != '/') sURL = path.join(req.path, sURL);
- sURL = "http://static.pcjs.org" + sURL.replace("/static/", "/");
+ sURL = "http://archive.pcjs.org" + sURL.replace("/archive/", "/");
}
}
return net.propagateParms(encodeURI(sURL), req);
diff --git a/notes.md b/notes.md
index 248cc7631..8bd4d2317 100644
--- a/notes.md
+++ b/notes.md
@@ -107,7 +107,7 @@ and replace using this regex:
For magazines (eg, BYTE), change:
- \!\[(.*?)\]\(../static/([^)]*) \"link:../static/(.*?):([0-9]*):([0-9]*)\"\)
+ \!\[(.*?)\]\(../archive/([^)]*) \"link:../archive/(.*?):([0-9]*):([0-9]*)\"\)
to:
diff --git a/pubs/pc/programming/manifest.xml b/pubs/pc/programming/manifest.xml
index 58b8bbc7f..8f11bf472 100644
--- a/pubs/pc/programming/manifest.xml
+++ b/pubs/pc/programming/manifest.xml
@@ -4,14 +4,14 @@
PC Programming Guides
PC-DOS 1.00 Disk Operating System
-
+
PC-DOS 1.10 Disk Operating System
-
+
The 8086 Book
-
+
\ No newline at end of file
diff --git a/pubs/pc/reference/ibm/5150/techref/manifest.xml b/pubs/pc/reference/ibm/5150/techref/manifest.xml
index 484029d07..df593d5e9 100644
--- a/pubs/pc/reference/ibm/5150/techref/manifest.xml
+++ b/pubs/pc/reference/ibm/5150/techref/manifest.xml
@@ -5,7 +5,7 @@
minuszerodegrees.net
IBM 5150 Technical Reference (August 1981)
-
+
Floppy Disk Adapter
diff --git a/pubs/pc/reference/ibm/5170/techref/manifest.xml b/pubs/pc/reference/ibm/5170/techref/manifest.xml
index 260f21507..2e57a9f05 100644
--- a/pubs/pc/reference/ibm/5170/techref/manifest.xml
+++ b/pubs/pc/reference/ibm/5170/techref/manifest.xml
@@ -5,7 +5,7 @@
minuszerodegrees.net
IBM 5170 Technical Reference (March 1984)
-
+
I/O Address Map
CMOS Addresses
BIOS Map
diff --git a/pubs/pc/reference/ibm/ega/manifest.xml b/pubs/pc/reference/ibm/ega/manifest.xml
index 9ee515ebe..f34d8e45f 100644
--- a/pubs/pc/reference/ibm/ega/manifest.xml
+++ b/pubs/pc/reference/ibm/ega/manifest.xml
@@ -5,7 +5,7 @@
minuszerodegrees.net
IBM EGA Technical Reference
-
+
Misc (3C2/3DA)
3C2: Misc Output
3C2: Input Status 0
diff --git a/pubs/pc/reference/intel/80286/manifest.xml b/pubs/pc/reference/intel/80286/manifest.xml
index facabded5..eb4a15dec 100644
--- a/pubs/pc/reference/intel/80286/manifest.xml
+++ b/pubs/pc/reference/intel/80286/manifest.xml
@@ -4,7 +4,7 @@
Intel 80286 References
80286 and 80287 Programmers Reference Manual (1987)
-
+
Memory Organization and Segmentation
\ No newline at end of file
diff --git a/modules/markout/lib/markout.js b/modules/markout/lib/markout.js
index 3e49e3fbb..9f782462b 100644
--- a/modules/markout/lib/markout.js
+++ b/modules/markout/lib/markout.js
@@ -966,18 +966,18 @@ MarkOut.prototype.convertMDImageLinks = function(sBlock, sIndent)
asParts.splice(2, 1);
}
/*
* If the image link (aMatch[2]) contains "static/" but the sURL is external, AND we're in
* "reveal mode", then transform sURL into a "static/" URL as well; encodeURL() will take care
* of the rest of the transformation.
*
* This feature is used with READMEs like /pubs/pc/programming/README.md, where normally we
* want to link to documents stored on sites like archive.org, minuszerodegrees.net or bitsavers,
* unless you're in "reveal mode", in which case we'll serve up our own "backup copies".
*
* The assumption here is that if we have "static" thumbs, then we should also have full "static"
* copies as well.
*/
- if (aMatch[2].indexOf("static/") >= 0 && sURL.indexOf("://") > 0 && (this.fDebug || net.hasParm(net.REVEAL_COMMAND, net.REVEAL_PDFS, this.req))) {
+ if (aMatch[2].indexOf("archive/") >= 0 && sURL.indexOf("://") > 0 && (this.fDebug || net.hasParm(net.REVEAL_COMMAND, net.REVEAL_PDFS, this.req))) {
sURL = aMatch[2].replace("/thumbs/", "/").replace(" 1.jpeg", ".pdf").replace(".jpg", ".pdf");
}
sURL = net.encodeURL(sURL, this.req, this.fDebug);
@@ -966,18 +966,18 @@ MarkOut.prototype.convertMDImageLinks = function(sBlock, sIndent)
}
/*
- * If the image link (aMatch[2]) contains "static/" but the sURL is external, AND we're in
- * "reveal mode", then transform sURL into a "static/" URL as well; encodeURL() will take care
+ * If the image link (aMatch[2]) contains "archive/" but the sURL is external, AND we're in
+ * "reveal mode", then transform sURL into a "archive/" URL as well; encodeURL() will take care
* of the rest of the transformation.
*
@@ -966,18 +966,18 @@ MarkOut.prototype.convertMDImageLinks = function(sBlock, sIndent)
* unless you're in "reveal mode", in which case we'll serve up our own "backup copies".
*
- * The assumption here is that if we have "static" thumbs, then we should also have full "static"
+ * The assumption here is that if we have "archive" thumbs, then we should also have full "archive"
* copies as well.
*/